@@ -39,6 +39,7 @@ from mypy_boto3_databrew.type_defs import (
     DeleteScheduleResponseTypeDef,
     DescribeDatasetResponseTypeDef,
     DescribeJobResponseTypeDef,
+    DescribeJobRunResponseTypeDef,
     DescribeProjectResponseTypeDef,
     DescribeRecipeResponseTypeDef,
     DescribeScheduleResponseTypeDef,
@@ -100,7 +101,7 @@ class Exceptions:
 
 class GlueDataBrewClient:
     """
-    [GlueDataBrew.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client)
+    [GlueDataBrew.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client)
     """
 
     meta: ClientMeta
@@ -110,12 +111,12 @@ class GlueDataBrewClient:
         self, Name: str, RecipeVersions: List[str]
     ) -> BatchDeleteRecipeVersionResponseTypeDef:
         """
-        [Client.batch_delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
+        [Client.batch_delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
         """
 
     def create_dataset(
@@ -126,7 +127,7 @@ class GlueDataBrewClient:
         Tags: Dict[str, str] = None,
     ) -> CreateDatasetResponseTypeDef:
         """
-        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
+        [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
         """
 
     def create_profile_job(
@@ -144,7 +145,7 @@ class GlueDataBrewClient:
         Timeout: int = None,
     ) -> CreateProfileJobResponseTypeDef:
         """
-        [Client.create_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
+        [Client.create_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
         """
 
     def create_project(
@@ -157,7 +158,7 @@ class GlueDataBrewClient:
         Tags: Dict[str, str] = None,
     ) -> CreateProjectResponseTypeDef:
         """
-        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_project)
+        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_project)
         """
 
     def create_recipe(
@@ -168,7 +169,7 @@ class GlueDataBrewClient:
         Tags: Dict[str, str] = None,
     ) -> CreateRecipeResponseTypeDef:
         """
-        [Client.create_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
+        [Client.create_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
         """
 
     def create_recipe_job(
@@ -188,7 +189,7 @@ class GlueDataBrewClient:
         Timeout: int = None,
     ) -> CreateRecipeJobResponseTypeDef:
         """
-        [Client.create_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
+        [Client.create_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
         """
 
     def create_schedule(
@@ -199,61 +200,66 @@ class GlueDataBrewClient:
         Tags: Dict[str, str] = None,
     ) -> CreateScheduleResponseTypeDef:
         """
-        [Client.create_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
+        [Client.create_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
         """
 
     def delete_dataset(self, Name: str) -> DeleteDatasetResponseTypeDef:
         """
-        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
+        [Client.delete_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
         """
 
     def delete_job(self, Name: str) -> DeleteJobResponseTypeDef:
         """
-        [Client.delete_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
+        [Client.delete_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
         """
 
     def delete_project(self, Name: str) -> DeleteProjectResponseTypeDef:
         """
-        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
+        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
         """
 
     def delete_recipe_version(
         self, Name: str, RecipeVersion: str
     ) -> DeleteRecipeVersionResponseTypeDef:
         """
-        [Client.delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
+        [Client.delete_recipe_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
         """
 
     def delete_schedule(self, Name: str) -> DeleteScheduleResponseTypeDef:
         """
-        [Client.delete_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
+        [Client.delete_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
         """
 
     def describe_dataset(self, Name: str) -> DescribeDatasetResponseTypeDef:
         """
-        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
+        [Client.describe_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
         """
 
     def describe_job(self, Name: str) -> DescribeJobResponseTypeDef:
         """
-        [Client.describe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        [Client.describe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        """
+
+    def describe_job_run(self, Name: str, RunId: str) -> DescribeJobRunResponseTypeDef:
+        """
+        [Client.describe_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
         """
 
     def describe_project(self, Name: str) -> DescribeProjectResponseTypeDef:
         """
-        [Client.describe_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
+        [Client.describe_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
         """
 
     def describe_recipe(
         self, Name: str, RecipeVersion: str = None
     ) -> DescribeRecipeResponseTypeDef:
         """
-        [Client.describe_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
+        [Client.describe_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
         """
 
     def describe_schedule(self, Name: str) -> DescribeScheduleResponseTypeDef:
         """
-        [Client.describe_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
+        [Client.describe_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
         """
 
     def generate_presigned_url(
@@ -264,21 +270,21 @@ class GlueDataBrewClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
         """
 
     def list_datasets(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
+        [Client.list_datasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
         """
 
     def list_job_runs(
         self, Name: str, MaxResults: int = None, NextToken: str = None
     ) -> ListJobRunsResponseTypeDef:
         """
-        [Client.list_job_runs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
+        [Client.list_job_runs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
         """
 
     def list_jobs(
@@ -289,45 +295,45 @@ class GlueDataBrewClient:
         ProjectName: str = None,
     ) -> ListJobsResponseTypeDef:
         """
-        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
+        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
         """
 
     def list_projects(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListProjectsResponseTypeDef:
         """
-        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
+        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
         """
 
     def list_recipe_versions(
         self, Name: str, MaxResults: int = None, NextToken: str = None
     ) -> ListRecipeVersionsResponseTypeDef:
         """
-        [Client.list_recipe_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
+        [Client.list_recipe_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
         """
 
     def list_recipes(
         self, MaxResults: int = None, NextToken: str = None, RecipeVersion: str = None
     ) -> ListRecipesResponseTypeDef:
         """
-        [Client.list_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
+        [Client.list_recipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
         """
 
     def list_schedules(
         self, JobName: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListSchedulesResponseTypeDef:
         """
-        [Client.list_schedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
+        [Client.list_schedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
         """
 
     def publish_recipe(self, Name: str, Description: str = None) -> PublishRecipeResponseTypeDef:
         """
-        [Client.publish_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
+        [Client.publish_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
         """
 
     def send_project_session_action(
@@ -340,41 +346,41 @@ class GlueDataBrewClient:
         ViewFrame: ViewFrameTypeDef = None,
     ) -> SendProjectSessionActionResponseTypeDef:
         """
-        [Client.send_project_session_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
+        [Client.send_project_session_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
         """
 
     def start_job_run(self, Name: str) -> StartJobRunResponseTypeDef:
         """
-        [Client.start_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
+        [Client.start_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
         """
 
     def start_project_session(
         self, Name: str, AssumeControl: bool = None
     ) -> StartProjectSessionResponseTypeDef:
         """
-        [Client.start_project_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
+        [Client.start_project_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
         """
 
     def stop_job_run(self, Name: str, RunId: str) -> StopJobRunResponseTypeDef:
         """
-        [Client.stop_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
+        [Client.stop_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
         """
 
     def update_dataset(
         self, Name: str, Input: "InputTypeDef", FormatOptions: "FormatOptionsTypeDef" = None
     ) -> UpdateDatasetResponseTypeDef:
         """
-        [Client.update_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
+        [Client.update_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
         """
 
     def update_profile_job(
@@ -390,21 +396,21 @@ class GlueDataBrewClient:
         Timeout: int = None,
     ) -> UpdateProfileJobResponseTypeDef:
         """
-        [Client.update_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
+        [Client.update_profile_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
         """
 
     def update_project(
         self, RoleArn: str, Name: str, Sample: "SampleTypeDef" = None
     ) -> UpdateProjectResponseTypeDef:
         """
-        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_project)
+        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_project)
         """
 
     def update_recipe(
         self, Name: str, Description: str = None, Steps: List["RecipeStepTypeDef"] = None
     ) -> UpdateRecipeResponseTypeDef:
         """
-        [Client.update_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
+        [Client.update_recipe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
         """
 
     def update_recipe_job(
@@ -420,38 +426,38 @@ class GlueDataBrewClient:
         Timeout: int = None,
     ) -> UpdateRecipeJobResponseTypeDef:
         """
-        [Client.update_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
+        [Client.update_recipe_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
         """
 
     def update_schedule(
         self, CronExpression: str, Name: str, JobNames: List[str] = None
     ) -> UpdateScheduleResponseTypeDef:
         """
-        [Client.update_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
+        [Client.update_schedule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
+        [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
+        [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
+        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
+        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
         """
 
     @overload
@@ -459,17 +465,17 @@ class GlueDataBrewClient:
         self, operation_name: Literal["list_recipe_versions"]
     ) -> ListRecipeVersionsPaginator:
         """
-        [Paginator.ListRecipeVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
+        [Paginator.ListRecipeVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
         """
-        [Paginator.ListRecipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
+        [Paginator.ListRecipes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
         """
-        [Paginator.ListSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.62/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
+        [Paginator.ListSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
         """
