@@ -61,6 +61,7 @@ __all__ = (
     "DeleteScheduleResponseTypeDef",
     "DescribeDatasetResponseTypeDef",
     "DescribeJobResponseTypeDef",
+    "DescribeJobRunResponseTypeDef",
     "DescribeProjectResponseTypeDef",
     "DescribeRecipeResponseTypeDef",
     "DescribeScheduleResponseTypeDef",
@@ -488,6 +489,38 @@ class DescribeJobResponseTypeDef(
     pass
 
 
+_RequiredDescribeJobRunResponseTypeDef = TypedDict(
+    "_RequiredDescribeJobRunResponseTypeDef", {"JobName": str}
+)
+_OptionalDescribeJobRunResponseTypeDef = TypedDict(
+    "_OptionalDescribeJobRunResponseTypeDef",
+    {
+        "Attempt": int,
+        "CompletedOn": datetime,
+        "DatasetName": str,
+        "ErrorMessage": str,
+        "ExecutionTime": int,
+        "RunId": str,
+        "State": Literal[
+            "STARTING", "RUNNING", "STOPPING", "STOPPED", "SUCCEEDED", "FAILED", "TIMEOUT"
+        ],
+        "LogSubscription": Literal["ENABLE", "DISABLE"],
+        "LogGroupName": str,
+        "Outputs": List["OutputTypeDef"],
+        "RecipeReference": "RecipeReferenceTypeDef",
+        "StartedBy": str,
+        "StartedOn": datetime,
+    },
+    total=False,
+)
+
+
+class DescribeJobRunResponseTypeDef(
+    _RequiredDescribeJobRunResponseTypeDef, _OptionalDescribeJobRunResponseTypeDef
+):
+    pass
+
+
 _RequiredDescribeProjectResponseTypeDef = TypedDict(
     "_RequiredDescribeProjectResponseTypeDef", {"Name": str}
 )
